import { Construct } from "constructs";
import * as tmroute53 from "../../aws-route53";
import { ICertificate } from "aws-cdk-lib/aws-certificatemanager";
import { DomainName, SecurityPolicy } from "@aws-cdk/aws-apigatewayv2-alpha";
import { ARecord, RecordTarget } from "aws-cdk-lib/aws-route53";
import { WeightedLatencyARecord } from "../../aws-route53";
export interface StandardDomainNameProps extends tmroute53.DomainNameProps {
    /**
     * The optional ACM certificate for this domain name.
     *
     * @default one is generated
     */
    readonly certificate?: ICertificate;
    /**
     * The Transport Layer Security (TLS) version + cipher suite for this domain name.
     *
     * @default SecurityPolicy.TLS_1_2
     */
    readonly securityPolicy?: SecurityPolicy;
}
/**
 * Standard construct used to create an API Gateway V2 Domain Name.
 */
export declare class StandardDomainName extends Construct {
    readonly domainName: tmroute53.DomainName;
    readonly certificate: ICertificate;
    readonly recordTarget: RecordTarget;
    readonly gatewayDomainName: DomainName;
    constructor(scope: Construct, id: string, props: StandardDomainNameProps);
    /**
     * Creates a route53 ARecord pointing to this domain name.
     */
    createARecord(): ARecord;
    /**
     * Creates a route53 weighted record pointing to this domain name.
     *
     * @param weight the initial weight; defaults to 0
     */
    createWeightedARecord(weight?: number): ARecord;
    /**
     * Creates a route53 latency record pointing to this domain name.
     */
    createLatencyARecord(): ARecord;
    /**
     * Creates a route53 weighted latency record pointing to this domain name.
     *
     * @param weight the initial weight; defaults to 0
     */
    createWeightedLatencyARecord(weight?: number): WeightedLatencyARecord;
    /**
     * Returns the FQDN of this domain name.
     */
    toString(): string;
}
