import { Construct } from "constructs";
import { IKey } from "aws-cdk-lib/aws-kms";
/**
 * Properties for AlertsTopic
 */
export interface AlertsTopicProps {
    /**
     * Overrides default topic display name.
     *
     * @default "CenterGaugeAlerts"
     */
    readonly displayName?: string;
    /**
     * Overrides the use of the default aws/sns KMS key for encryption
     *
     * @default uses AWS managed SNS KMS key
     */
    readonly masterKey?: IKey;
    /**
     * Overrides the default alerts URL.
     *
     * @default https://alerts.centergauge.com/
     */
    readonly url?: string;
}
/**
 * Sets up an SNS Topic that will send notifications to CenterGauge.
 */
export declare class AlertsTopic extends Construct {
    constructor(scope: Construct, id: string, props: AlertsTopicProps);
}
