import { BehaviorOptions, Distribution, DistributionProps, ErrorResponse, GeoRestriction, HttpVersion, IOrigin, PriceClass, SecurityPolicyProtocol, SSLMethod } from "aws-cdk-lib/aws-cloudfront";
import { Certificate } from "aws-cdk-lib/aws-certificatemanager";
import { IBucket } from "aws-cdk-lib/aws-s3";
import { Construct } from "constructs";
import { BehaviorBuilder } from "./behavior-builder";
import { DomainName } from "../../aws-route53";
export interface WebsiteRedirectFunctionOptions {
    /**
     * Identifier to use when creating the CloudFront Function.
     *
     * @default "RedirectFunction"
     */
    readonly id?: string;
    /**
     * Optional domain to redirect to if the host header does not match.
     */
    readonly apexDomain?: string;
    /**
     * The default file to request when the URI ends with a '/'. Set to en empty string to disable.
     *
     * @default "index.html"
     */
    readonly indexFile?: string;
}
export interface WebsiteOriginOptions {
    readonly scope: Construct;
    readonly origin: IOrigin;
    readonly redirectFunctionOptions: WebsiteRedirectFunctionOptions;
}
export declare class DistributionBuilder {
    protected props: DistributionProps;
    protected defaultBehaviorBuilder: BehaviorBuilder;
    protected additionalBehaviorBuilders: Record<string, BehaviorBuilder>;
    constructor(defaultBehaviorBuilder: BehaviorBuilder);
    defaultBehavior(): BehaviorBuilder;
    additionalBehaviors(additionalBehaviors?: Record<string, BehaviorOptions>): DistributionBuilder;
    additionalBehavior(pattern: string, origin: IOrigin): BehaviorBuilder;
    certificate(certificate?: Certificate): DistributionBuilder;
    comment(comment?: string): DistributionBuilder;
    defaultRootObject(defaultRootObject?: string): DistributionBuilder;
    domainNames(domainNames?: string[]): DistributionBuilder;
    domainName(domainName: string | DomainName): DistributionBuilder;
    enabled(enabled?: boolean): DistributionBuilder;
    enableIpv6(enableIpv6?: boolean): DistributionBuilder;
    enableLogging(enableLogging?: boolean): DistributionBuilder;
    geoRestriction(geoRestriction?: GeoRestriction): DistributionBuilder;
    httpVersion(httpVersion?: HttpVersion): DistributionBuilder;
    logBucket(logBucket?: IBucket): DistributionBuilder;
    logIncludesCookies(logIncludesCookies?: boolean): DistributionBuilder;
    logFilePrefix(logFilePrefix?: string): DistributionBuilder;
    priceClass(priceClass?: PriceClass): DistributionBuilder;
    webAclId(webAclId?: string): DistributionBuilder;
    errorResponses(errorResponses?: ErrorResponse[]): DistributionBuilder;
    errorResponse(errorResponse: ErrorResponse): DistributionBuilder;
    minimumProtocolVersion(minimumProtocolVersion?: SecurityPolicyProtocol): DistributionBuilder;
    sslSupportMethod(sslSupportMethod?: SSLMethod): DistributionBuilder;
    defaults(): DistributionBuilder;
    build(): DistributionProps;
    toDistribution(scope: Construct, id: string): Distribution;
    static fromOrigin(origin: IOrigin): DistributionBuilder;
    static fromWebsiteOrigin(origin: IOrigin, scope: Construct, options?: WebsiteRedirectFunctionOptions): DistributionBuilder;
}
