import { WeightedARecord, WeightedARecordProps } from "./weighted-a-record";
import { Construct } from "constructs";
import { LatencyARecord, LatencyARecordProps } from "./latency-a-record";
import { IRecordSet } from "aws-cdk-lib/aws-route53/lib/record-set";
import { RemovalPolicy, ResourceEnvironment, Stack } from "aws-cdk-lib";
export interface WeightedLatencyARecordOptions {
    /**
     * Value to use as a prefix on the latency route53 record.
     *
     * @default lbr
     */
    readonly latencyRecordPrefix?: string;
}
/**
 * Properties for WeightedLatencyARecord.
 */
export interface WeightedLatencyARecordProps extends WeightedARecordProps, LatencyARecordProps, WeightedLatencyARecordOptions {
}
/**
 * An WeightedARecord that uses as LatencyARecord internally to do both weight and latency based routing.
 */
export declare class WeightedLatencyARecord extends Construct implements IRecordSet {
    readonly weightedRecord: WeightedARecord;
    readonly latencyRecord: LatencyARecord;
    readonly domainName: string;
    readonly env: ResourceEnvironment;
    readonly stack: Stack;
    constructor(scope: Construct, id: string, props: WeightedLatencyARecordProps);
    applyRemovalPolicy(policy: RemovalPolicy): void;
}
