import { Construct } from "constructs";
import { Bucket } from "aws-cdk-lib/aws-s3";
import { OriginAccessIdentity } from "aws-cdk-lib/aws-cloudfront";
import { RemovalPolicy } from "aws-cdk-lib/core";
import { BucketDeployment } from "aws-cdk-lib/aws-s3-deployment";
import { Duration } from "aws-cdk-lib";
/**
 * Properties for CloudFrontBucket.
 */
export interface CloudFrontBucketProps {
    /**
     * Policy to apply when the bucket is removed from this stack.
     * @default RemovalPolicy.RETAIN
     */
    readonly removalPolicy?: RemovalPolicy;
    /**
     * Whether all objects should be automatically deleted when the bucket is removed from the stack or when the stack is deleted.
     * Requires the removalPolicy to be set to RemovalPolicy.DESTROY.
     *
     * @default false
     */
    readonly autoDeleteObjects?: boolean;
}
/**
 * Simple Construct for creating buckets that will be accessed directly by CloudFront as an Origin.
 */
export declare class CloudFrontBucket extends Construct {
    readonly bucket: Bucket;
    readonly bucketName: string;
    readonly originAccessIdentity: OriginAccessIdentity;
    readonly originAccessIdentityId: string;
    constructor(scope: Construct, id: string, props: CloudFrontBucketProps);
    /**
     * Helper method to deploy local assets to the created bucket. Ths function assumes
     * CloudFront invalidation requests will be sent for mutable files to serve new content.
     * For more complicated deployments, use BucketDeployment directly.
     *
     * @param path the path to the local assets
     * @param maxAge the length of time to browsers will cache files; default is Duration.minutes(15)
     * @param sMaxAge the length of time CloudFront will cache files; default is Duration.days(7)
     * @param prune
     */
    deploy(path: string, maxAge?: Duration, sMaxAge?: Duration, prune?: boolean): BucketDeployment;
}
