import { RemovalPolicy } from "aws-cdk-lib/core";
import { Construct } from "constructs";
import { Bucket, RedirectTarget, RoutingRule } from "aws-cdk-lib/aws-s3";
import { LatencyARecord, WeightedARecord, WeightedLatencyARecord } from "../../aws-route53";
import { ARecord, IHostedZone } from "aws-cdk-lib/aws-route53";
import { Duration } from "aws-cdk-lib";
import { BucketDeployment } from "aws-cdk-lib/aws-s3-deployment";
/**
 * Domain name properties for a bucket based website.
 */
export interface WebsiteDomainNameProps {
    readonly prefix?: string;
    readonly zone: string | IHostedZone;
    readonly weight?: number;
    readonly latency?: boolean;
    readonly create?: boolean;
}
/**
 * Properties for WebsiteBucket.
 */
export interface WebsiteBucketProps {
    /**
     * Policy to apply when the bucket is removed from this stack.
     * @default RemovalPolicy.RETAIN
     */
    readonly removalPolicy?: RemovalPolicy;
    /**
     * Whether all objects should be automatically deleted when the bucket is removed from the stack or when the stack is deleted.
     * Requires the removalPolicy to be set to RemovalPolicy.DESTROY.
     *
     * @default false
     */
    readonly autoDeleteObjects?: boolean;
    readonly domainName?: WebsiteDomainNameProps;
    readonly websiteIndexDocument?: string;
    readonly websiteErrorDocument?: string;
    readonly websiteRedirect?: RedirectTarget;
    readonly websiteRoutingRules?: RoutingRule[];
}
/**
 * Simple Construct for creating buckets that will be accessed directly as a website.
 */
export declare class WebsiteBucket extends Construct {
    readonly bucket: Bucket;
    readonly bucketName: string;
    readonly bucketWebsiteUrl: string;
    readonly bucketWebsiteDomainName: string;
    readonly record: ARecord | WeightedARecord | LatencyARecord | WeightedLatencyARecord;
    constructor(scope: Construct, id: string, props: WebsiteBucketProps);
    /**
     * Helper method to deploy local assets to the created bucket. Ths function assumes
     * CloudFront invalidation requests will be sent for mutable files to serve new content.
     * For more complicated deployments, use BucketDeployment directly.
     *
     * @param path the path to the local assets
     * @param maxAge the length of time to browsers will cache files; default is Duration.minutes(15)
     * @param sMaxAge the length of time CloudFront will cache files; default is Duration.days(7)
     * @param prune
     */
    deploy(path: string, maxAge?: Duration, sMaxAge?: Duration, prune?: boolean): BucketDeployment;
}
